import {
  select,
  json,
  tsv,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  schemeCategory10,
  schemeSpectral
  
} from 'd3';

import {loadAndProData} from './loadAndProData'
import {colorLegend} from './colorLegend'


const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendG = svg.append('g')
    .attr('transform', `translate(30,280)`)

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const colorScale = scaleOrdinal()

const colorValue = d => d.properties.economy

loadAndProData().then(countries => { 
  colorScale
  .domain(countries.features.map(colorValue))
  .domain(colorScale.domain().sort().reverse())
  .range(schemeSpectral[colorScale.domain().length])
  
      colorLegendG.call(colorLegend, {
      colorScale,
      circleRadius: 10,
      spacing: 30,
      textOffset: 10,
      backGroundRectWidth:230
    });

  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
  		.attr('fill', d => colorScale(colorValue(d)))
    .append('title')
     .text(d => d.properties.name + colorValue(d));
  
})
